/**
 * $Id: queue.h,v 1.4 2004/09/04 07:08:01 jklein Exp $
 * $Author: jklein $
 * $Log: queue.h,v $
 * Revision 1.4  2004/09/04 07:08:01  jklein
 * fixed "const spointer" to "sconstpointer".
 *
 * Revision 1.3  2004/06/26 06:58:13  jklein
 * small fix in each header files.
 *
 * Revision 1.2  2004/06/21 16:44:17  jklein
 * Added iterator.
 *
 */


#ifndef _SCALE_QUEUE_H_
#define _SCALE_QUEUE_H_

#include <scale/commons.h>
#include <scale/list.h>


typedef slist_t squeue_t;

#define s_queue_alloc() (squeue_t *)s_list_alloc()
#define s_queue_free(q)	s_list_free((slist_t *)(q))
#define s_queue_size(q)	s_list_size((slist_t *)(q))
#define s_queue_enqueue(q, c) s_list_add((slist_t *)(q), c)

spointer		s_queue_dequeue(squeue_t *);
spointer		s_queue_front(squeue_t *);



#endif /* _SCALE_QUEUE_H_ */
